"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2936 import (
        AbstractAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2937 import (
        AbstractShaftCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2938 import (
        AbstractShaftOrHousingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2939 import (
        AbstractShaftToMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2940 import (
        AGMAGleasonConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2941 import (
        AGMAGleasonConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2942 import (
        AGMAGleasonConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2943 import (
        AssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2944 import (
        BearingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2945 import (
        BeltConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2946 import (
        BeltDriveCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2947 import (
        BevelDifferentialGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2948 import (
        BevelDifferentialGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2949 import (
        BevelDifferentialGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2950 import (
        BevelDifferentialPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2951 import (
        BevelDifferentialSunGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2952 import (
        BevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2953 import (
        BevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2954 import (
        BevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2955 import (
        BoltCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2956 import (
        BoltedJointCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2957 import (
        ClutchCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2958 import (
        ClutchConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2959 import (
        ClutchHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2960 import (
        CoaxialConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2961 import (
        ComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2962 import (
        ConceptCouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2963 import (
        ConceptCouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2964 import (
        ConceptCouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2965 import (
        ConceptGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2966 import (
        ConceptGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2967 import (
        ConceptGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2968 import (
        ConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2969 import (
        ConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2970 import (
        ConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2971 import (
        ConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2972 import (
        ConnectorCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2973 import (
        CouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2974 import (
        CouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2975 import (
        CouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2976 import (
        CVTBeltConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2977 import (
        CVTCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2978 import (
        CVTPulleyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2979 import (
        CycloidalAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2980 import (
        CycloidalDiscCentralBearingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2981 import (
        CycloidalDiscCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2982 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2983 import (
        CylindricalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2984 import (
        CylindricalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2985 import (
        CylindricalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2986 import (
        CylindricalPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2987 import (
        DatumCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2988 import (
        DutyCycleEfficiencyResults,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2989 import (
        ExternalCADModelCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2990 import (
        FaceGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2991 import (
        FaceGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2992 import (
        FaceGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2993 import (
        FEPartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2994 import (
        FlexiblePinAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2995 import (
        GearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2996 import (
        GearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2997 import (
        GearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2998 import (
        GuideDxfModelCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2999 import (
        HypoidGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3000 import (
        HypoidGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3001 import (
        HypoidGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3002 import (
        InterMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3003 import (
        KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3004 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3005 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3006 import (
        KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3007 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3008 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3009 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3010 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3011 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3012 import (
        MassDiscCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3013 import (
        MeasurementComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3014 import (
        MicrophoneArrayCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3015 import (
        MicrophoneCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3016 import (
        MountableComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3017 import (
        OilSealCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3018 import (
        PartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3019 import (
        PartToPartShearCouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3020 import (
        PartToPartShearCouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3021 import (
        PartToPartShearCouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3022 import (
        PlanetaryConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3023 import (
        PlanetaryGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3024 import (
        PlanetCarrierCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3025 import (
        PointLoadCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3026 import (
        PowerLoadCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3027 import (
        PulleyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3028 import (
        RingPinsCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3029 import (
        RingPinsToDiscConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3030 import (
        RollingRingAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3031 import (
        RollingRingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3032 import (
        RollingRingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3033 import (
        RootAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3034 import (
        ShaftCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3035 import (
        ShaftDutyCycleSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3036 import (
        ShaftHubConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3037 import (
        ShaftToMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3038 import (
        SpecialisedAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3039 import (
        SpiralBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3040 import (
        SpiralBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3041 import (
        SpiralBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3042 import (
        SpringDamperCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3043 import (
        SpringDamperConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3044 import (
        SpringDamperHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3045 import (
        StraightBevelDiffGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3046 import (
        StraightBevelDiffGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3047 import (
        StraightBevelDiffGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3048 import (
        StraightBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3049 import (
        StraightBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3050 import (
        StraightBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3051 import (
        StraightBevelPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3052 import (
        StraightBevelSunGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3053 import (
        SynchroniserCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3054 import (
        SynchroniserHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3055 import (
        SynchroniserPartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3056 import (
        SynchroniserSleeveCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3057 import (
        TorqueConverterCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3058 import (
        TorqueConverterConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3059 import (
        TorqueConverterPumpCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3060 import (
        TorqueConverterTurbineCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3061 import (
        UnbalancedMassCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3062 import (
        VirtualComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3063 import (
        WormGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3064 import (
        WormGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3065 import (
        WormGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3066 import (
        ZerolBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3067 import (
        ZerolBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3068 import (
        ZerolBevelGearSetCompoundSystemDeflection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.system_deflections.compound._2936": [
            "AbstractAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2937": [
            "AbstractShaftCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2938": [
            "AbstractShaftOrHousingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2939": [
            "AbstractShaftToMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2940": [
            "AGMAGleasonConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2941": [
            "AGMAGleasonConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2942": [
            "AGMAGleasonConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2943": [
            "AssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2944": [
            "BearingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2945": [
            "BeltConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2946": [
            "BeltDriveCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2947": [
            "BevelDifferentialGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2948": [
            "BevelDifferentialGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2949": [
            "BevelDifferentialGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2950": [
            "BevelDifferentialPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2951": [
            "BevelDifferentialSunGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2952": [
            "BevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2953": [
            "BevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2954": [
            "BevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2955": [
            "BoltCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2956": [
            "BoltedJointCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2957": [
            "ClutchCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2958": [
            "ClutchConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2959": [
            "ClutchHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2960": [
            "CoaxialConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2961": [
            "ComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2962": [
            "ConceptCouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2963": [
            "ConceptCouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2964": [
            "ConceptCouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2965": [
            "ConceptGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2966": [
            "ConceptGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2967": [
            "ConceptGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2968": [
            "ConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2969": [
            "ConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2970": [
            "ConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2971": [
            "ConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2972": [
            "ConnectorCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2973": [
            "CouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2974": [
            "CouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2975": [
            "CouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2976": [
            "CVTBeltConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2977": [
            "CVTCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2978": [
            "CVTPulleyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2979": [
            "CycloidalAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2980": [
            "CycloidalDiscCentralBearingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2981": [
            "CycloidalDiscCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2982": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2983": [
            "CylindricalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2984": [
            "CylindricalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2985": [
            "CylindricalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2986": [
            "CylindricalPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2987": [
            "DatumCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2988": [
            "DutyCycleEfficiencyResults"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2989": [
            "ExternalCADModelCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2990": [
            "FaceGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2991": [
            "FaceGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2992": [
            "FaceGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2993": [
            "FEPartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2994": [
            "FlexiblePinAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2995": [
            "GearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2996": [
            "GearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2997": [
            "GearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2998": [
            "GuideDxfModelCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2999": [
            "HypoidGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3000": [
            "HypoidGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3001": [
            "HypoidGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3002": [
            "InterMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3003": [
            "KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3004": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3005": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3006": [
            "KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3007": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3008": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3009": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3010": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3011": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3012": [
            "MassDiscCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3013": [
            "MeasurementComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3014": [
            "MicrophoneArrayCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3015": [
            "MicrophoneCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3016": [
            "MountableComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3017": [
            "OilSealCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3018": [
            "PartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3019": [
            "PartToPartShearCouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3020": [
            "PartToPartShearCouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3021": [
            "PartToPartShearCouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3022": [
            "PlanetaryConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3023": [
            "PlanetaryGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3024": [
            "PlanetCarrierCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3025": [
            "PointLoadCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3026": [
            "PowerLoadCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3027": [
            "PulleyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3028": [
            "RingPinsCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3029": [
            "RingPinsToDiscConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3030": [
            "RollingRingAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3031": [
            "RollingRingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3032": [
            "RollingRingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3033": [
            "RootAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3034": [
            "ShaftCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3035": [
            "ShaftDutyCycleSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3036": [
            "ShaftHubConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3037": [
            "ShaftToMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3038": [
            "SpecialisedAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3039": [
            "SpiralBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3040": [
            "SpiralBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3041": [
            "SpiralBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3042": [
            "SpringDamperCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3043": [
            "SpringDamperConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3044": [
            "SpringDamperHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3045": [
            "StraightBevelDiffGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3046": [
            "StraightBevelDiffGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3047": [
            "StraightBevelDiffGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3048": [
            "StraightBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3049": [
            "StraightBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3050": [
            "StraightBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3051": [
            "StraightBevelPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3052": [
            "StraightBevelSunGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3053": [
            "SynchroniserCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3054": [
            "SynchroniserHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3055": [
            "SynchroniserPartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3056": [
            "SynchroniserSleeveCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3057": [
            "TorqueConverterCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3058": [
            "TorqueConverterConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3059": [
            "TorqueConverterPumpCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3060": [
            "TorqueConverterTurbineCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3061": [
            "UnbalancedMassCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3062": [
            "VirtualComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3063": [
            "WormGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3064": [
            "WormGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3065": [
            "WormGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3066": [
            "ZerolBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3067": [
            "ZerolBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3068": [
            "ZerolBevelGearSetCompoundSystemDeflection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundSystemDeflection",
    "AbstractShaftCompoundSystemDeflection",
    "AbstractShaftOrHousingCompoundSystemDeflection",
    "AbstractShaftToMountableComponentConnectionCompoundSystemDeflection",
    "AGMAGleasonConicalGearCompoundSystemDeflection",
    "AGMAGleasonConicalGearMeshCompoundSystemDeflection",
    "AGMAGleasonConicalGearSetCompoundSystemDeflection",
    "AssemblyCompoundSystemDeflection",
    "BearingCompoundSystemDeflection",
    "BeltConnectionCompoundSystemDeflection",
    "BeltDriveCompoundSystemDeflection",
    "BevelDifferentialGearCompoundSystemDeflection",
    "BevelDifferentialGearMeshCompoundSystemDeflection",
    "BevelDifferentialGearSetCompoundSystemDeflection",
    "BevelDifferentialPlanetGearCompoundSystemDeflection",
    "BevelDifferentialSunGearCompoundSystemDeflection",
    "BevelGearCompoundSystemDeflection",
    "BevelGearMeshCompoundSystemDeflection",
    "BevelGearSetCompoundSystemDeflection",
    "BoltCompoundSystemDeflection",
    "BoltedJointCompoundSystemDeflection",
    "ClutchCompoundSystemDeflection",
    "ClutchConnectionCompoundSystemDeflection",
    "ClutchHalfCompoundSystemDeflection",
    "CoaxialConnectionCompoundSystemDeflection",
    "ComponentCompoundSystemDeflection",
    "ConceptCouplingCompoundSystemDeflection",
    "ConceptCouplingConnectionCompoundSystemDeflection",
    "ConceptCouplingHalfCompoundSystemDeflection",
    "ConceptGearCompoundSystemDeflection",
    "ConceptGearMeshCompoundSystemDeflection",
    "ConceptGearSetCompoundSystemDeflection",
    "ConicalGearCompoundSystemDeflection",
    "ConicalGearMeshCompoundSystemDeflection",
    "ConicalGearSetCompoundSystemDeflection",
    "ConnectionCompoundSystemDeflection",
    "ConnectorCompoundSystemDeflection",
    "CouplingCompoundSystemDeflection",
    "CouplingConnectionCompoundSystemDeflection",
    "CouplingHalfCompoundSystemDeflection",
    "CVTBeltConnectionCompoundSystemDeflection",
    "CVTCompoundSystemDeflection",
    "CVTPulleyCompoundSystemDeflection",
    "CycloidalAssemblyCompoundSystemDeflection",
    "CycloidalDiscCentralBearingConnectionCompoundSystemDeflection",
    "CycloidalDiscCompoundSystemDeflection",
    "CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection",
    "CylindricalGearCompoundSystemDeflection",
    "CylindricalGearMeshCompoundSystemDeflection",
    "CylindricalGearSetCompoundSystemDeflection",
    "CylindricalPlanetGearCompoundSystemDeflection",
    "DatumCompoundSystemDeflection",
    "DutyCycleEfficiencyResults",
    "ExternalCADModelCompoundSystemDeflection",
    "FaceGearCompoundSystemDeflection",
    "FaceGearMeshCompoundSystemDeflection",
    "FaceGearSetCompoundSystemDeflection",
    "FEPartCompoundSystemDeflection",
    "FlexiblePinAssemblyCompoundSystemDeflection",
    "GearCompoundSystemDeflection",
    "GearMeshCompoundSystemDeflection",
    "GearSetCompoundSystemDeflection",
    "GuideDxfModelCompoundSystemDeflection",
    "HypoidGearCompoundSystemDeflection",
    "HypoidGearMeshCompoundSystemDeflection",
    "HypoidGearSetCompoundSystemDeflection",
    "InterMountableComponentConnectionCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection",
    "MassDiscCompoundSystemDeflection",
    "MeasurementComponentCompoundSystemDeflection",
    "MicrophoneArrayCompoundSystemDeflection",
    "MicrophoneCompoundSystemDeflection",
    "MountableComponentCompoundSystemDeflection",
    "OilSealCompoundSystemDeflection",
    "PartCompoundSystemDeflection",
    "PartToPartShearCouplingCompoundSystemDeflection",
    "PartToPartShearCouplingConnectionCompoundSystemDeflection",
    "PartToPartShearCouplingHalfCompoundSystemDeflection",
    "PlanetaryConnectionCompoundSystemDeflection",
    "PlanetaryGearSetCompoundSystemDeflection",
    "PlanetCarrierCompoundSystemDeflection",
    "PointLoadCompoundSystemDeflection",
    "PowerLoadCompoundSystemDeflection",
    "PulleyCompoundSystemDeflection",
    "RingPinsCompoundSystemDeflection",
    "RingPinsToDiscConnectionCompoundSystemDeflection",
    "RollingRingAssemblyCompoundSystemDeflection",
    "RollingRingCompoundSystemDeflection",
    "RollingRingConnectionCompoundSystemDeflection",
    "RootAssemblyCompoundSystemDeflection",
    "ShaftCompoundSystemDeflection",
    "ShaftDutyCycleSystemDeflection",
    "ShaftHubConnectionCompoundSystemDeflection",
    "ShaftToMountableComponentConnectionCompoundSystemDeflection",
    "SpecialisedAssemblyCompoundSystemDeflection",
    "SpiralBevelGearCompoundSystemDeflection",
    "SpiralBevelGearMeshCompoundSystemDeflection",
    "SpiralBevelGearSetCompoundSystemDeflection",
    "SpringDamperCompoundSystemDeflection",
    "SpringDamperConnectionCompoundSystemDeflection",
    "SpringDamperHalfCompoundSystemDeflection",
    "StraightBevelDiffGearCompoundSystemDeflection",
    "StraightBevelDiffGearMeshCompoundSystemDeflection",
    "StraightBevelDiffGearSetCompoundSystemDeflection",
    "StraightBevelGearCompoundSystemDeflection",
    "StraightBevelGearMeshCompoundSystemDeflection",
    "StraightBevelGearSetCompoundSystemDeflection",
    "StraightBevelPlanetGearCompoundSystemDeflection",
    "StraightBevelSunGearCompoundSystemDeflection",
    "SynchroniserCompoundSystemDeflection",
    "SynchroniserHalfCompoundSystemDeflection",
    "SynchroniserPartCompoundSystemDeflection",
    "SynchroniserSleeveCompoundSystemDeflection",
    "TorqueConverterCompoundSystemDeflection",
    "TorqueConverterConnectionCompoundSystemDeflection",
    "TorqueConverterPumpCompoundSystemDeflection",
    "TorqueConverterTurbineCompoundSystemDeflection",
    "UnbalancedMassCompoundSystemDeflection",
    "VirtualComponentCompoundSystemDeflection",
    "WormGearCompoundSystemDeflection",
    "WormGearMeshCompoundSystemDeflection",
    "WormGearSetCompoundSystemDeflection",
    "ZerolBevelGearCompoundSystemDeflection",
    "ZerolBevelGearMeshCompoundSystemDeflection",
    "ZerolBevelGearSetCompoundSystemDeflection",
)



"""GearLoadCaseBase"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import utility
from mastapy._private.gears.analysis import _1256
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_GEAR_LOAD_CASE_BASE = python_net_import(
    "SMT.MastaAPI.Gears.LoadCase", "GearLoadCaseBase"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.load_case.worm import _899
    from mastapy._private.gears.load_case.face import _902
    from mastapy._private.gears.load_case.cylindrical import _905
    from mastapy._private.gears.load_case.conical import _908
    from mastapy._private.gears.load_case.concept import _911
    from mastapy._private.gears.load_case.bevel import _914
    from mastapy._private.gears.analysis import _1253

    Self = TypeVar("Self", bound="GearLoadCaseBase")
    CastSelf = TypeVar("CastSelf", bound="GearLoadCaseBase._Cast_GearLoadCaseBase")


__docformat__ = "restructuredtext en"
__all__ = ("GearLoadCaseBase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearLoadCaseBase:
    """Special nested class for casting GearLoadCaseBase to subclasses."""

    __parent__: "GearLoadCaseBase"

    @property
    def gear_design_analysis(self: "CastSelf") -> "_1256.GearDesignAnalysis":
        return self.__parent__._cast(_1256.GearDesignAnalysis)

    @property
    def abstract_gear_analysis(self: "CastSelf") -> "_1253.AbstractGearAnalysis":
        from mastapy._private.gears.analysis import _1253

        return self.__parent__._cast(_1253.AbstractGearAnalysis)

    @property
    def worm_gear_load_case(self: "CastSelf") -> "_899.WormGearLoadCase":
        from mastapy._private.gears.load_case.worm import _899

        return self.__parent__._cast(_899.WormGearLoadCase)

    @property
    def face_gear_load_case(self: "CastSelf") -> "_902.FaceGearLoadCase":
        from mastapy._private.gears.load_case.face import _902

        return self.__parent__._cast(_902.FaceGearLoadCase)

    @property
    def cylindrical_gear_load_case(self: "CastSelf") -> "_905.CylindricalGearLoadCase":
        from mastapy._private.gears.load_case.cylindrical import _905

        return self.__parent__._cast(_905.CylindricalGearLoadCase)

    @property
    def conical_gear_load_case(self: "CastSelf") -> "_908.ConicalGearLoadCase":
        from mastapy._private.gears.load_case.conical import _908

        return self.__parent__._cast(_908.ConicalGearLoadCase)

    @property
    def concept_gear_load_case(self: "CastSelf") -> "_911.ConceptGearLoadCase":
        from mastapy._private.gears.load_case.concept import _911

        return self.__parent__._cast(_911.ConceptGearLoadCase)

    @property
    def bevel_load_case(self: "CastSelf") -> "_914.BevelLoadCase":
        from mastapy._private.gears.load_case.bevel import _914

        return self.__parent__._cast(_914.BevelLoadCase)

    @property
    def gear_load_case_base(self: "CastSelf") -> "GearLoadCaseBase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class GearLoadCaseBase(_1256.GearDesignAnalysis):
    """GearLoadCaseBase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_LOAD_CASE_BASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def duration(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Duration

        if temp is None:
            return 0.0

        return temp

    @property
    def gear_temperature(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.GearTemperature

        if temp is None:
            return 0.0

        return temp

    @gear_temperature.setter
    @enforce_parameter_types
    def gear_temperature(self: "Self", value: "float") -> None:
        self.wrapped.GearTemperature = float(value) if value is not None else 0.0

    @property
    def rotation_speed(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RotationSpeed

        if temp is None:
            return 0.0

        return temp

    @rotation_speed.setter
    @enforce_parameter_types
    def rotation_speed(self: "Self", value: "float") -> None:
        self.wrapped.RotationSpeed = float(value) if value is not None else 0.0

    @property
    def sump_temperature(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.SumpTemperature

        if temp is None:
            return 0.0

        return temp

    @sump_temperature.setter
    @enforce_parameter_types
    def sump_temperature(self: "Self", value: "float") -> None:
        self.wrapped.SumpTemperature = float(value) if value is not None else 0.0

    @property
    def cast_to(self: "Self") -> "_Cast_GearLoadCaseBase":
        """Cast to another type.

        Returns:
            _Cast_GearLoadCaseBase
        """
        return _Cast_GearLoadCaseBase(self)



"""CADFaceGroup"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CAD_FACE_GROUP = python_net_import("SMT.MastaAPI.Geometry.TwoD", "CADFaceGroup")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.geometry.two_d import _320

    Self = TypeVar("Self", bound="CADFaceGroup")
    CastSelf = TypeVar("CastSelf", bound="CADFaceGroup._Cast_CADFaceGroup")


__docformat__ = "restructuredtext en"
__all__ = ("CADFaceGroup",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CADFaceGroup:
    """Special nested class for casting CADFaceGroup to subclasses."""

    __parent__: "CADFaceGroup"

    @property
    def cad_face_group(self: "CastSelf") -> "CADFaceGroup":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CADFaceGroup(_0.APIBase):
    """CADFaceGroup

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CAD_FACE_GROUP

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @enforce_parameter_types
    def add_face(self: "Self", moniker: "str") -> "_320.CADFace":
        """mastapy._private.geometry.two_d.CADFace

        Args:
            moniker (str)
        """
        moniker = str(moniker)
        method_result = self.wrapped.AddFace(moniker if moniker else "")
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @property
    def cast_to(self: "Self") -> "_Cast_CADFaceGroup":
        """Cast to another type.

        Returns:
            _Cast_CADFaceGroup
        """
        return _Cast_CADFaceGroup(self)



"""InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
    _7326,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_INTER_MOUNTABLE_COMPONENT_CONNECTION_COMPOUND_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation.Compound",
    "InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
        _7225,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
        _7296,
        _7300,
        _7303,
        _7308,
        _7313,
        _7318,
        _7321,
        _7324,
        _7329,
        _7331,
        _7339,
        _7345,
        _7350,
        _7354,
        _7358,
        _7361,
        _7364,
        _7374,
        _7383,
        _7386,
        _7393,
        _7396,
        _7399,
        _7402,
        _7411,
        _7417,
        _7420,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7704,
        _7708,
    )
    from mastapy._private.system_model.analyses_and_results import _2734

    Self = TypeVar(
        "Self",
        bound="InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation",
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation._Cast_InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation",
    )


__docformat__ = "restructuredtext en"
__all__ = (
    "InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation",
)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation:
    """Special nested class for casting InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation to subclasses."""

    __parent__: "InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation"

    @property
    def connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7326.ConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        return self.__parent__._cast(
            _7326.ConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def connection_compound_analysis(
        self: "CastSelf",
    ) -> "_7704.ConnectionCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7704,
        )

        return self.__parent__._cast(_7704.ConnectionCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7708.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7708,
        )

        return self.__parent__._cast(_7708.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7296.AGMAGleasonConicalGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7296,
        )

        return self.__parent__._cast(
            _7296.AGMAGleasonConicalGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def belt_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7300.BeltConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7300,
        )

        return self.__parent__._cast(
            _7300.BeltConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def bevel_differential_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7303.BevelDifferentialGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7303,
        )

        return self.__parent__._cast(
            _7303.BevelDifferentialGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def bevel_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7308.BevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7308,
        )

        return self.__parent__._cast(
            _7308.BevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def clutch_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7313.ClutchConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7313,
        )

        return self.__parent__._cast(
            _7313.ClutchConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def concept_coupling_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7318.ConceptCouplingConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7318,
        )

        return self.__parent__._cast(
            _7318.ConceptCouplingConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def concept_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7321.ConceptGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7321,
        )

        return self.__parent__._cast(
            _7321.ConceptGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def conical_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7324.ConicalGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7324,
        )

        return self.__parent__._cast(
            _7324.ConicalGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def coupling_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7329.CouplingConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7329,
        )

        return self.__parent__._cast(
            _7329.CouplingConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def cvt_belt_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7331.CVTBeltConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7331,
        )

        return self.__parent__._cast(
            _7331.CVTBeltConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def cylindrical_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7339.CylindricalGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7339,
        )

        return self.__parent__._cast(
            _7339.CylindricalGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def face_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7345.FaceGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7345,
        )

        return self.__parent__._cast(
            _7345.FaceGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7350.GearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7350,
        )

        return self.__parent__._cast(
            _7350.GearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def hypoid_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7354.HypoidGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7354,
        )

        return self.__parent__._cast(
            _7354.HypoidGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7358.KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7358,
        )

        return self.__parent__._cast(
            _7358.KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7361.KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7361,
        )

        return self.__parent__._cast(
            _7361.KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7364.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7364,
        )

        return self.__parent__._cast(
            _7364.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def part_to_part_shear_coupling_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7374.PartToPartShearCouplingConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7374,
        )

        return self.__parent__._cast(
            _7374.PartToPartShearCouplingConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def ring_pins_to_disc_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7383.RingPinsToDiscConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7383,
        )

        return self.__parent__._cast(
            _7383.RingPinsToDiscConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def rolling_ring_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7386.RollingRingConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7386,
        )

        return self.__parent__._cast(
            _7386.RollingRingConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def spiral_bevel_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7393.SpiralBevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7393,
        )

        return self.__parent__._cast(
            _7393.SpiralBevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def spring_damper_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> (
        "_7396.SpringDamperConnectionCompoundAdvancedTimeSteppingAnalysisForModulation"
    ):
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7396,
        )

        return self.__parent__._cast(
            _7396.SpringDamperConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def straight_bevel_diff_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7399.StraightBevelDiffGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7399,
        )

        return self.__parent__._cast(
            _7399.StraightBevelDiffGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def straight_bevel_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7402.StraightBevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7402,
        )

        return self.__parent__._cast(
            _7402.StraightBevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def torque_converter_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7411.TorqueConverterConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7411,
        )

        return self.__parent__._cast(
            _7411.TorqueConverterConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def worm_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7417.WormGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7417,
        )

        return self.__parent__._cast(
            _7417.WormGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def zerol_bevel_gear_mesh_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7420.ZerolBevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import (
            _7420,
        )

        return self.__parent__._cast(
            _7420.ZerolBevelGearMeshCompoundAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def inter_mountable_component_connection_compound_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation(
    _7326.ConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
):
    """InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    """

    TYPE: ClassVar[
        "Type"
    ] = _INTER_MOUNTABLE_COMPONENT_CONNECTION_COMPOUND_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def connection_analysis_cases(
        self: "Self",
    ) -> "List[_7225.InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def connection_analysis_cases_ready(
        self: "Self",
    ) -> "List[_7225.InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation":
        """Cast to another type.

        Returns:
            _Cast_InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation
        """
        return _Cast_InterMountableComponentConnectionCompoundAdvancedTimeSteppingAnalysisForModulation(
            self
        )



"""ScuffingFlashTemperatureRatingMethod"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_SCUFFING_FLASH_TEMPERATURE_RATING_METHOD = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical", "ScuffingFlashTemperatureRatingMethod"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ScuffingFlashTemperatureRatingMethod")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ScuffingFlashTemperatureRatingMethod._Cast_ScuffingFlashTemperatureRatingMethod",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ScuffingFlashTemperatureRatingMethod",)


class ScuffingFlashTemperatureRatingMethod(Enum):
    """ScuffingFlashTemperatureRatingMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _SCUFFING_FLASH_TEMPERATURE_RATING_METHOD

    ISOTR_1398912000 = 0
    ISOTS_6336202017 = 1
    ISOTS_6336202022 = 2
    DIN_399041987 = 3


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ScuffingFlashTemperatureRatingMethod.__setattr__ = __enum_setattr
ScuffingFlashTemperatureRatingMethod.__delattr__ = __enum_delattr



"""AdvancedTimeSteppingAnalysisForModulationModeViewOptions"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item
from mastapy._private.system_model.part_model.gears import _2588
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION_MODE_VIEW_OPTIONS = python_net_import(
    "SMT.MastaAPI.SystemModel.Drawing.Options",
    "AdvancedTimeSteppingAnalysisForModulationModeViewOptions",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
        _7159,
        _7160,
    )

    Self = TypeVar(
        "Self", bound="AdvancedTimeSteppingAnalysisForModulationModeViewOptions"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="AdvancedTimeSteppingAnalysisForModulationModeViewOptions._Cast_AdvancedTimeSteppingAnalysisForModulationModeViewOptions",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AdvancedTimeSteppingAnalysisForModulationModeViewOptions",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AdvancedTimeSteppingAnalysisForModulationModeViewOptions:
    """Special nested class for casting AdvancedTimeSteppingAnalysisForModulationModeViewOptions to subclasses."""

    __parent__: "AdvancedTimeSteppingAnalysisForModulationModeViewOptions"

    @property
    def advanced_time_stepping_analysis_for_modulation_mode_view_options(
        self: "CastSelf",
    ) -> "AdvancedTimeSteppingAnalysisForModulationModeViewOptions":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class AdvancedTimeSteppingAnalysisForModulationModeViewOptions(_0.APIBase):
    """AdvancedTimeSteppingAnalysisForModulationModeViewOptions

    This is a mastapy class.
    """

    TYPE: ClassVar[
        "Type"
    ] = _ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION_MODE_VIEW_OPTIONS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def excitations_type(self: "Self") -> "_7159.AtsamExcitationsOrOthers":
        """mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.AtsamExcitationsOrOthers"""
        temp = self.wrapped.ExcitationsType

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation.AtsamExcitationsOrOthers",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7159",
            "AtsamExcitationsOrOthers",
        )(value)

    @excitations_type.setter
    @enforce_parameter_types
    def excitations_type(self: "Self", value: "_7159.AtsamExcitationsOrOthers") -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation.AtsamExcitationsOrOthers",
        )
        self.wrapped.ExcitationsType = value

    @property
    def gear_set(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_GearSet":
        """ListWithSelectedItem[mastapy._private.system_model.part_model.gears.GearSet]"""
        temp = self.wrapped.GearSet

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_GearSet",
        )(temp)

    @gear_set.setter
    @enforce_parameter_types
    def gear_set(self: "Self", value: "_2588.GearSet") -> None:
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_GearSet.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_GearSet.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.GearSet = value

    @property
    def large_time_step(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.LargeTimeStep

        if temp is None:
            return 0

        return temp

    @large_time_step.setter
    @enforce_parameter_types
    def large_time_step(self: "Self", value: "int") -> None:
        self.wrapped.LargeTimeStep = int(value) if value is not None else 0

    @property
    def mode_view_options(self: "Self") -> "_7160.AtsamNaturalFrequencyViewOption":
        """mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.AtsamNaturalFrequencyViewOption"""
        temp = self.wrapped.ModeViewOptions

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation.AtsamNaturalFrequencyViewOption",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7160",
            "AtsamNaturalFrequencyViewOption",
        )(value)

    @mode_view_options.setter
    @enforce_parameter_types
    def mode_view_options(
        self: "Self", value: "_7160.AtsamNaturalFrequencyViewOption"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation.AtsamNaturalFrequencyViewOption",
        )
        self.wrapped.ModeViewOptions = value

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_AdvancedTimeSteppingAnalysisForModulationModeViewOptions":
        """Cast to another type.

        Returns:
            _Cast_AdvancedTimeSteppingAnalysisForModulationModeViewOptions
        """
        return _Cast_AdvancedTimeSteppingAnalysisForModulationModeViewOptions(self)



"""PartCriticalSpeedAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.analysis_cases import _7713
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_PART_CRITICAL_SPEED_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.CriticalSpeedAnalyses",
    "PartCriticalSpeedAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.part_model import _2524
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
        _6725,
        _6685,
        _6686,
        _6687,
        _6689,
        _6691,
        _6692,
        _6693,
        _6695,
        _6696,
        _6698,
        _6699,
        _6700,
        _6701,
        _6703,
        _6704,
        _6705,
        _6707,
        _6708,
        _6710,
        _6712,
        _6713,
        _6714,
        _6716,
        _6717,
        _6719,
        _6721,
        _6723,
        _6724,
        _6729,
        _6730,
        _6731,
        _6733,
        _6735,
        _6737,
        _6738,
        _6739,
        _6740,
        _6741,
        _6743,
        _6744,
        _6745,
        _6746,
        _6748,
        _6749,
        _6750,
        _6752,
        _6754,
        _6756,
        _6757,
        _6759,
        _6760,
        _6762,
        _6763,
        _6764,
        _6765,
        _6766,
        _6767,
        _6768,
        _6771,
        _6772,
        _6774,
        _6775,
        _6776,
        _6777,
        _6778,
        _6779,
        _6781,
        _6783,
        _6784,
        _6785,
        _6786,
        _6788,
        _6789,
        _6791,
        _6793,
        _6794,
        _6795,
        _6797,
        _6798,
        _6800,
        _6801,
        _6802,
        _6803,
        _6804,
        _6805,
        _6806,
        _6808,
        _6809,
        _6810,
        _6811,
        _6812,
        _6813,
        _6815,
        _6816,
        _6818,
    )
    from mastapy._private.system_model.drawing import _2300
    from mastapy._private.system_model.analyses_and_results.analysis_cases import _7710
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="PartCriticalSpeedAnalysis")
    CastSelf = TypeVar(
        "CastSelf", bound="PartCriticalSpeedAnalysis._Cast_PartCriticalSpeedAnalysis"
    )


__docformat__ = "restructuredtext en"
__all__ = ("PartCriticalSpeedAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PartCriticalSpeedAnalysis:
    """Special nested class for casting PartCriticalSpeedAnalysis to subclasses."""

    __parent__: "PartCriticalSpeedAnalysis"

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7713.PartStaticLoadAnalysisCase":
        return self.__parent__._cast(_7713.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7710.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7710,
        )

        return self.__parent__._cast(_7710.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def abstract_assembly_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6685.AbstractAssemblyCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6685,
        )

        return self.__parent__._cast(_6685.AbstractAssemblyCriticalSpeedAnalysis)

    @property
    def abstract_shaft_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6686.AbstractShaftCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6686,
        )

        return self.__parent__._cast(_6686.AbstractShaftCriticalSpeedAnalysis)

    @property
    def abstract_shaft_or_housing_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6687.AbstractShaftOrHousingCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6687,
        )

        return self.__parent__._cast(_6687.AbstractShaftOrHousingCriticalSpeedAnalysis)

    @property
    def agma_gleason_conical_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6689.AGMAGleasonConicalGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6689,
        )

        return self.__parent__._cast(_6689.AGMAGleasonConicalGearCriticalSpeedAnalysis)

    @property
    def agma_gleason_conical_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6691.AGMAGleasonConicalGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6691,
        )

        return self.__parent__._cast(
            _6691.AGMAGleasonConicalGearSetCriticalSpeedAnalysis
        )

    @property
    def assembly_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6692.AssemblyCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6692,
        )

        return self.__parent__._cast(_6692.AssemblyCriticalSpeedAnalysis)

    @property
    def bearing_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6693.BearingCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6693,
        )

        return self.__parent__._cast(_6693.BearingCriticalSpeedAnalysis)

    @property
    def belt_drive_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6695.BeltDriveCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6695,
        )

        return self.__parent__._cast(_6695.BeltDriveCriticalSpeedAnalysis)

    @property
    def bevel_differential_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6696.BevelDifferentialGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6696,
        )

        return self.__parent__._cast(_6696.BevelDifferentialGearCriticalSpeedAnalysis)

    @property
    def bevel_differential_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6698.BevelDifferentialGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6698,
        )

        return self.__parent__._cast(
            _6698.BevelDifferentialGearSetCriticalSpeedAnalysis
        )

    @property
    def bevel_differential_planet_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6699.BevelDifferentialPlanetGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6699,
        )

        return self.__parent__._cast(
            _6699.BevelDifferentialPlanetGearCriticalSpeedAnalysis
        )

    @property
    def bevel_differential_sun_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6700.BevelDifferentialSunGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6700,
        )

        return self.__parent__._cast(
            _6700.BevelDifferentialSunGearCriticalSpeedAnalysis
        )

    @property
    def bevel_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6701.BevelGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6701,
        )

        return self.__parent__._cast(_6701.BevelGearCriticalSpeedAnalysis)

    @property
    def bevel_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6703.BevelGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6703,
        )

        return self.__parent__._cast(_6703.BevelGearSetCriticalSpeedAnalysis)

    @property
    def bolt_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6704.BoltCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6704,
        )

        return self.__parent__._cast(_6704.BoltCriticalSpeedAnalysis)

    @property
    def bolted_joint_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6705.BoltedJointCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6705,
        )

        return self.__parent__._cast(_6705.BoltedJointCriticalSpeedAnalysis)

    @property
    def clutch_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6707.ClutchCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6707,
        )

        return self.__parent__._cast(_6707.ClutchCriticalSpeedAnalysis)

    @property
    def clutch_half_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6708.ClutchHalfCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6708,
        )

        return self.__parent__._cast(_6708.ClutchHalfCriticalSpeedAnalysis)

    @property
    def component_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6710.ComponentCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6710,
        )

        return self.__parent__._cast(_6710.ComponentCriticalSpeedAnalysis)

    @property
    def concept_coupling_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6712.ConceptCouplingCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6712,
        )

        return self.__parent__._cast(_6712.ConceptCouplingCriticalSpeedAnalysis)

    @property
    def concept_coupling_half_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6713.ConceptCouplingHalfCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6713,
        )

        return self.__parent__._cast(_6713.ConceptCouplingHalfCriticalSpeedAnalysis)

    @property
    def concept_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6714.ConceptGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6714,
        )

        return self.__parent__._cast(_6714.ConceptGearCriticalSpeedAnalysis)

    @property
    def concept_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6716.ConceptGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6716,
        )

        return self.__parent__._cast(_6716.ConceptGearSetCriticalSpeedAnalysis)

    @property
    def conical_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6717.ConicalGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6717,
        )

        return self.__parent__._cast(_6717.ConicalGearCriticalSpeedAnalysis)

    @property
    def conical_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6719.ConicalGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6719,
        )

        return self.__parent__._cast(_6719.ConicalGearSetCriticalSpeedAnalysis)

    @property
    def connector_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6721.ConnectorCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6721,
        )

        return self.__parent__._cast(_6721.ConnectorCriticalSpeedAnalysis)

    @property
    def coupling_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6723.CouplingCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6723,
        )

        return self.__parent__._cast(_6723.CouplingCriticalSpeedAnalysis)

    @property
    def coupling_half_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6724.CouplingHalfCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6724,
        )

        return self.__parent__._cast(_6724.CouplingHalfCriticalSpeedAnalysis)

    @property
    def cvt_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6729.CVTCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6729,
        )

        return self.__parent__._cast(_6729.CVTCriticalSpeedAnalysis)

    @property
    def cvt_pulley_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6730.CVTPulleyCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6730,
        )

        return self.__parent__._cast(_6730.CVTPulleyCriticalSpeedAnalysis)

    @property
    def cycloidal_assembly_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6731.CycloidalAssemblyCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6731,
        )

        return self.__parent__._cast(_6731.CycloidalAssemblyCriticalSpeedAnalysis)

    @property
    def cycloidal_disc_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6733.CycloidalDiscCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6733,
        )

        return self.__parent__._cast(_6733.CycloidalDiscCriticalSpeedAnalysis)

    @property
    def cylindrical_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6735.CylindricalGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6735,
        )

        return self.__parent__._cast(_6735.CylindricalGearCriticalSpeedAnalysis)

    @property
    def cylindrical_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6737.CylindricalGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6737,
        )

        return self.__parent__._cast(_6737.CylindricalGearSetCriticalSpeedAnalysis)

    @property
    def cylindrical_planet_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6738.CylindricalPlanetGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6738,
        )

        return self.__parent__._cast(_6738.CylindricalPlanetGearCriticalSpeedAnalysis)

    @property
    def datum_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6739.DatumCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6739,
        )

        return self.__parent__._cast(_6739.DatumCriticalSpeedAnalysis)

    @property
    def external_cad_model_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6740.ExternalCADModelCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6740,
        )

        return self.__parent__._cast(_6740.ExternalCADModelCriticalSpeedAnalysis)

    @property
    def face_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6741.FaceGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6741,
        )

        return self.__parent__._cast(_6741.FaceGearCriticalSpeedAnalysis)

    @property
    def face_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6743.FaceGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6743,
        )

        return self.__parent__._cast(_6743.FaceGearSetCriticalSpeedAnalysis)

    @property
    def fe_part_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6744.FEPartCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6744,
        )

        return self.__parent__._cast(_6744.FEPartCriticalSpeedAnalysis)

    @property
    def flexible_pin_assembly_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6745.FlexiblePinAssemblyCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6745,
        )

        return self.__parent__._cast(_6745.FlexiblePinAssemblyCriticalSpeedAnalysis)

    @property
    def gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6746.GearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6746,
        )

        return self.__parent__._cast(_6746.GearCriticalSpeedAnalysis)

    @property
    def gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6748.GearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6748,
        )

        return self.__parent__._cast(_6748.GearSetCriticalSpeedAnalysis)

    @property
    def guide_dxf_model_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6749.GuideDxfModelCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6749,
        )

        return self.__parent__._cast(_6749.GuideDxfModelCriticalSpeedAnalysis)

    @property
    def hypoid_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6750.HypoidGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6750,
        )

        return self.__parent__._cast(_6750.HypoidGearCriticalSpeedAnalysis)

    @property
    def hypoid_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6752.HypoidGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6752,
        )

        return self.__parent__._cast(_6752.HypoidGearSetCriticalSpeedAnalysis)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6754.KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6754,
        )

        return self.__parent__._cast(
            _6754.KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6756.KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6756,
        )

        return self.__parent__._cast(
            _6756.KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6757.KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6757,
        )

        return self.__parent__._cast(
            _6757.KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6759.KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6759,
        )

        return self.__parent__._cast(
            _6759.KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6760.KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6760,
        )

        return self.__parent__._cast(
            _6760.KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6762.KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6762,
        )

        return self.__parent__._cast(
            _6762.KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis
        )

    @property
    def mass_disc_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6763.MassDiscCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6763,
        )

        return self.__parent__._cast(_6763.MassDiscCriticalSpeedAnalysis)

    @property
    def measurement_component_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6764.MeasurementComponentCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6764,
        )

        return self.__parent__._cast(_6764.MeasurementComponentCriticalSpeedAnalysis)

    @property
    def microphone_array_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6765.MicrophoneArrayCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6765,
        )

        return self.__parent__._cast(_6765.MicrophoneArrayCriticalSpeedAnalysis)

    @property
    def microphone_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6766.MicrophoneCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6766,
        )

        return self.__parent__._cast(_6766.MicrophoneCriticalSpeedAnalysis)

    @property
    def mountable_component_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6767.MountableComponentCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6767,
        )

        return self.__parent__._cast(_6767.MountableComponentCriticalSpeedAnalysis)

    @property
    def oil_seal_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6768.OilSealCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6768,
        )

        return self.__parent__._cast(_6768.OilSealCriticalSpeedAnalysis)

    @property
    def part_to_part_shear_coupling_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6771.PartToPartShearCouplingCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6771,
        )

        return self.__parent__._cast(_6771.PartToPartShearCouplingCriticalSpeedAnalysis)

    @property
    def part_to_part_shear_coupling_half_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6772.PartToPartShearCouplingHalfCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6772,
        )

        return self.__parent__._cast(
            _6772.PartToPartShearCouplingHalfCriticalSpeedAnalysis
        )

    @property
    def planetary_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6774.PlanetaryGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6774,
        )

        return self.__parent__._cast(_6774.PlanetaryGearSetCriticalSpeedAnalysis)

    @property
    def planet_carrier_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6775.PlanetCarrierCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6775,
        )

        return self.__parent__._cast(_6775.PlanetCarrierCriticalSpeedAnalysis)

    @property
    def point_load_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6776.PointLoadCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6776,
        )

        return self.__parent__._cast(_6776.PointLoadCriticalSpeedAnalysis)

    @property
    def power_load_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6777.PowerLoadCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6777,
        )

        return self.__parent__._cast(_6777.PowerLoadCriticalSpeedAnalysis)

    @property
    def pulley_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6778.PulleyCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6778,
        )

        return self.__parent__._cast(_6778.PulleyCriticalSpeedAnalysis)

    @property
    def ring_pins_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6779.RingPinsCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6779,
        )

        return self.__parent__._cast(_6779.RingPinsCriticalSpeedAnalysis)

    @property
    def rolling_ring_assembly_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6781.RollingRingAssemblyCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6781,
        )

        return self.__parent__._cast(_6781.RollingRingAssemblyCriticalSpeedAnalysis)

    @property
    def rolling_ring_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6783.RollingRingCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6783,
        )

        return self.__parent__._cast(_6783.RollingRingCriticalSpeedAnalysis)

    @property
    def root_assembly_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6784.RootAssemblyCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6784,
        )

        return self.__parent__._cast(_6784.RootAssemblyCriticalSpeedAnalysis)

    @property
    def shaft_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6785.ShaftCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6785,
        )

        return self.__parent__._cast(_6785.ShaftCriticalSpeedAnalysis)

    @property
    def shaft_hub_connection_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6786.ShaftHubConnectionCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6786,
        )

        return self.__parent__._cast(_6786.ShaftHubConnectionCriticalSpeedAnalysis)

    @property
    def specialised_assembly_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6788.SpecialisedAssemblyCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6788,
        )

        return self.__parent__._cast(_6788.SpecialisedAssemblyCriticalSpeedAnalysis)

    @property
    def spiral_bevel_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6789.SpiralBevelGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6789,
        )

        return self.__parent__._cast(_6789.SpiralBevelGearCriticalSpeedAnalysis)

    @property
    def spiral_bevel_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6791.SpiralBevelGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6791,
        )

        return self.__parent__._cast(_6791.SpiralBevelGearSetCriticalSpeedAnalysis)

    @property
    def spring_damper_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6793.SpringDamperCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6793,
        )

        return self.__parent__._cast(_6793.SpringDamperCriticalSpeedAnalysis)

    @property
    def spring_damper_half_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6794.SpringDamperHalfCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6794,
        )

        return self.__parent__._cast(_6794.SpringDamperHalfCriticalSpeedAnalysis)

    @property
    def straight_bevel_diff_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6795.StraightBevelDiffGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6795,
        )

        return self.__parent__._cast(_6795.StraightBevelDiffGearCriticalSpeedAnalysis)

    @property
    def straight_bevel_diff_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6797.StraightBevelDiffGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6797,
        )

        return self.__parent__._cast(
            _6797.StraightBevelDiffGearSetCriticalSpeedAnalysis
        )

    @property
    def straight_bevel_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6798.StraightBevelGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6798,
        )

        return self.__parent__._cast(_6798.StraightBevelGearCriticalSpeedAnalysis)

    @property
    def straight_bevel_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6800.StraightBevelGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6800,
        )

        return self.__parent__._cast(_6800.StraightBevelGearSetCriticalSpeedAnalysis)

    @property
    def straight_bevel_planet_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6801.StraightBevelPlanetGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6801,
        )

        return self.__parent__._cast(_6801.StraightBevelPlanetGearCriticalSpeedAnalysis)

    @property
    def straight_bevel_sun_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6802.StraightBevelSunGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6802,
        )

        return self.__parent__._cast(_6802.StraightBevelSunGearCriticalSpeedAnalysis)

    @property
    def synchroniser_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6803.SynchroniserCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6803,
        )

        return self.__parent__._cast(_6803.SynchroniserCriticalSpeedAnalysis)

    @property
    def synchroniser_half_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6804.SynchroniserHalfCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6804,
        )

        return self.__parent__._cast(_6804.SynchroniserHalfCriticalSpeedAnalysis)

    @property
    def synchroniser_part_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6805.SynchroniserPartCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6805,
        )

        return self.__parent__._cast(_6805.SynchroniserPartCriticalSpeedAnalysis)

    @property
    def synchroniser_sleeve_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6806.SynchroniserSleeveCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6806,
        )

        return self.__parent__._cast(_6806.SynchroniserSleeveCriticalSpeedAnalysis)

    @property
    def torque_converter_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6808.TorqueConverterCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6808,
        )

        return self.__parent__._cast(_6808.TorqueConverterCriticalSpeedAnalysis)

    @property
    def torque_converter_pump_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6809.TorqueConverterPumpCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6809,
        )

        return self.__parent__._cast(_6809.TorqueConverterPumpCriticalSpeedAnalysis)

    @property
    def torque_converter_turbine_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6810.TorqueConverterTurbineCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6810,
        )

        return self.__parent__._cast(_6810.TorqueConverterTurbineCriticalSpeedAnalysis)

    @property
    def unbalanced_mass_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6811.UnbalancedMassCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6811,
        )

        return self.__parent__._cast(_6811.UnbalancedMassCriticalSpeedAnalysis)

    @property
    def virtual_component_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6812.VirtualComponentCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6812,
        )

        return self.__parent__._cast(_6812.VirtualComponentCriticalSpeedAnalysis)

    @property
    def worm_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6813.WormGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6813,
        )

        return self.__parent__._cast(_6813.WormGearCriticalSpeedAnalysis)

    @property
    def worm_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6815.WormGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6815,
        )

        return self.__parent__._cast(_6815.WormGearSetCriticalSpeedAnalysis)

    @property
    def zerol_bevel_gear_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6816.ZerolBevelGearCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6816,
        )

        return self.__parent__._cast(_6816.ZerolBevelGearCriticalSpeedAnalysis)

    @property
    def zerol_bevel_gear_set_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6818.ZerolBevelGearSetCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6818,
        )

        return self.__parent__._cast(_6818.ZerolBevelGearSetCriticalSpeedAnalysis)

    @property
    def part_critical_speed_analysis(self: "CastSelf") -> "PartCriticalSpeedAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class PartCriticalSpeedAnalysis(_7713.PartStaticLoadAnalysisCase):
    """PartCriticalSpeedAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PART_CRITICAL_SPEED_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def component_design(self: "Self") -> "_2524.Part":
        """mastapy._private.system_model.part_model.Part

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def critical_speed_analysis(self: "Self") -> "_6725.CriticalSpeedAnalysis":
        """mastapy._private.system_model.analyses_and_results.critical_speed_analyses.CriticalSpeedAnalysis

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CriticalSpeedAnalysis

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    def create_viewable(self: "Self") -> "_2300.CriticalSpeedAnalysisViewable":
        """mastapy._private.system_model.drawing.CriticalSpeedAnalysisViewable"""
        method_result = self.wrapped.CreateViewable()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @property
    def cast_to(self: "Self") -> "_Cast_PartCriticalSpeedAnalysis":
        """Cast to another type.

        Returns:
            _Cast_PartCriticalSpeedAnalysis
        """
        return _Cast_PartCriticalSpeedAnalysis(self)



"""CylindricalGearSetCompoundSystemDeflection"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
    _2997,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_SET_COMPOUND_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Compound",
    "CylindricalGearSetCompoundSystemDeflection",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1140
    from mastapy._private.system_model.part_model.gears import _2582
    from mastapy._private.gears.rating.cylindrical import _474, _475
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _2827,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
        _2983,
        _2984,
        _3023,
        _3038,
        _2936,
        _3018,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7711,
        _7708,
    )
    from mastapy._private.system_model.analyses_and_results import _2734

    Self = TypeVar("Self", bound="CylindricalGearSetCompoundSystemDeflection")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearSetCompoundSystemDeflection._Cast_CylindricalGearSetCompoundSystemDeflection",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearSetCompoundSystemDeflection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearSetCompoundSystemDeflection:
    """Special nested class for casting CylindricalGearSetCompoundSystemDeflection to subclasses."""

    __parent__: "CylindricalGearSetCompoundSystemDeflection"

    @property
    def gear_set_compound_system_deflection(
        self: "CastSelf",
    ) -> "_2997.GearSetCompoundSystemDeflection":
        return self.__parent__._cast(_2997.GearSetCompoundSystemDeflection)

    @property
    def specialised_assembly_compound_system_deflection(
        self: "CastSelf",
    ) -> "_3038.SpecialisedAssemblyCompoundSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
            _3038,
        )

        return self.__parent__._cast(_3038.SpecialisedAssemblyCompoundSystemDeflection)

    @property
    def abstract_assembly_compound_system_deflection(
        self: "CastSelf",
    ) -> "_2936.AbstractAssemblyCompoundSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
            _2936,
        )

        return self.__parent__._cast(_2936.AbstractAssemblyCompoundSystemDeflection)

    @property
    def part_compound_system_deflection(
        self: "CastSelf",
    ) -> "_3018.PartCompoundSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
            _3018,
        )

        return self.__parent__._cast(_3018.PartCompoundSystemDeflection)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7711.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7711,
        )

        return self.__parent__._cast(_7711.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7708.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7708,
        )

        return self.__parent__._cast(_7708.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def planetary_gear_set_compound_system_deflection(
        self: "CastSelf",
    ) -> "_3023.PlanetaryGearSetCompoundSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
            _3023,
        )

        return self.__parent__._cast(_3023.PlanetaryGearSetCompoundSystemDeflection)

    @property
    def cylindrical_gear_set_compound_system_deflection(
        self: "CastSelf",
    ) -> "CylindricalGearSetCompoundSystemDeflection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CylindricalGearSetCompoundSystemDeflection(_2997.GearSetCompoundSystemDeflection):
    """CylindricalGearSetCompoundSystemDeflection

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_SET_COMPOUND_SYSTEM_DEFLECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def advanced_ltca_results(
        self: "Self",
    ) -> "_1140.CylindricalGearSetMicroGeometryDutyCycle":
        """mastapy._private.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearSetMicroGeometryDutyCycle

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AdvancedLTCAResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def advanced_ltca_results_only_first_planetary_mesh(
        self: "Self",
    ) -> "_1140.CylindricalGearSetMicroGeometryDutyCycle":
        """mastapy._private.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearSetMicroGeometryDutyCycle

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AdvancedLTCAResultsOnlyFirstPlanetaryMesh

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def component_design(self: "Self") -> "_2582.CylindricalGearSet":
        """mastapy._private.system_model.part_model.gears.CylindricalGearSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def assembly_design(self: "Self") -> "_2582.CylindricalGearSet":
        """mastapy._private.system_model.part_model.gears.CylindricalGearSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def basic_ltca_results(
        self: "Self",
    ) -> "_1140.CylindricalGearSetMicroGeometryDutyCycle":
        """mastapy._private.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearSetMicroGeometryDutyCycle

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BasicLTCAResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def basic_ltca_results_only_first_planetary_mesh(
        self: "Self",
    ) -> "_1140.CylindricalGearSetMicroGeometryDutyCycle":
        """mastapy._private.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearSetMicroGeometryDutyCycle

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BasicLTCAResultsOnlyFirstPlanetaryMesh

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cylindrical_gear_set_rating(
        self: "Self",
    ) -> "_474.CylindricalGearSetDutyCycleRating":
        """mastapy._private.gears.rating.cylindrical.CylindricalGearSetDutyCycleRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearSetRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cylindrical_gear_set_rating_using_basic_ltca(
        self: "Self",
    ) -> "_474.CylindricalGearSetDutyCycleRating":
        """mastapy._private.gears.rating.cylindrical.CylindricalGearSetDutyCycleRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearSetRatingUsingBasicLTCA

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def load_case_rating_with_lowest_safety_factor_for_scuffing(
        self: "Self",
    ) -> "_475.CylindricalGearSetRating":
        """mastapy._private.gears.rating.cylindrical.CylindricalGearSetRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadCaseRatingWithLowestSafetyFactorForScuffing

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_2827.CylindricalGearSetSystemDeflectionWithLTCAResults]":
        """List[mastapy._private.system_model.analyses_and_results.system_deflections.CylindricalGearSetSystemDeflectionWithLTCAResults]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cylindrical_gears_compound_system_deflection(
        self: "Self",
    ) -> "List[_2983.CylindricalGearCompoundSystemDeflection]":
        """List[mastapy._private.system_model.analyses_and_results.system_deflections.compound.CylindricalGearCompoundSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearsCompoundSystemDeflection

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cylindrical_meshes_compound_system_deflection(
        self: "Self",
    ) -> "List[_2984.CylindricalGearMeshCompoundSystemDeflection]":
        """List[mastapy._private.system_model.analyses_and_results.system_deflections.compound.CylindricalGearMeshCompoundSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalMeshesCompoundSystemDeflection

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_2827.CylindricalGearSetSystemDeflectionWithLTCAResults]":
        """List[mastapy._private.system_model.analyses_and_results.system_deflections.CylindricalGearSetSystemDeflectionWithLTCAResults]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearSetCompoundSystemDeflection":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearSetCompoundSystemDeflection
        """
        return _Cast_CylindricalGearSetCompoundSystemDeflection(self)
